@@ -198,7 +198,7 @@ static void *sgnTilde_new(void)
 ZEXY_SETUP void sgn_tilde_setup(void)
 {
   sgnTilde_class = zexy_new("sgn~",
-                            sgnTilde_new, 0, t_sgnTilde, 0, "");
+                            sgnTilde_new, 0, t_sgnTilde, CLASS_DEFAULT, "");
   zexy_addmethod(sgnTilde_class, (t_method)nullfn, "signal", "");
   zexy_addmethod(sgnTilde_class, (t_method)sgnTilde_dsp, "dsp", "!");
 
