@@ -170,7 +170,7 @@ static void symbol2list_help(t_symbol2list*UNUSED(x))
 static t_class* zclass_setup(const char*name)
 {
   t_class*c = zexy_new(name,
-                       symbol2list_new, symbol2list_free, t_symbol2list, 0, "*");
+                       symbol2list_new, symbol2list_free, t_symbol2list, CLASS_DEFAULT, "*");
   class_addsymbol (c, symbol2list_symbol);
   class_addbang   (c, symbol2list_bang);
   zexy_addmethod(c, (t_method)symbol2list_delimiter, "", "s");
